@@ -6,11 +6,10 @@ import pytest
 
 from tuxrun.__main__ import main
 from tuxrun.devices import Device
-from tuxrun.devices.qemu import QemuArmv5
 from tuxrun.devices.fvp import FVPMorelloAndroid
+from tuxrun.devices.qemu import QemuArmv5
 from tuxrun.exceptions import InvalidArgument
 
-
 BASE = (Path(__file__) / "..").resolve()
 
 
@@ -234,6 +233,10 @@ def artefacts(tmp_path):
             ["--device", "qemu-i386", "--tests", "v4l2"],
             "qemu-i386-v4l2.yaml",
         ),
+        (
+            ["--device", "qemu-i386", "--tests", "vdso"],
+            "qemu-i386-vdso.yaml",
+        ),
         (
             [
                 "--device",
@@ -382,6 +385,15 @@ def artefacts(tmp_path):
             ],
             "qemu-x86_64-rootfs-zst.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-x86_64",
+                "--rootfs",
+                "https://example.com/rootfs.ext4",
+            ],
+            "qemu-x86_64-rootfs.yaml",
+        ),
         (
             [
                 "--device",
@@ -876,7 +888,9 @@ def test_definition(monkeypatch, mocker, tmpdir, artefacts, args, filename):
     monkeypatch.setattr("tuxrun.__main__.sys.argv", ["tuxrun"] + args)
     mocker.patch("tuxrun.__main__.Runtime.select", side_effect=Exception)
     mocker.patch("tuxrun.assets.__download_and_cache__", side_effect=lambda a, b: a)
-    mocker.patch("tuxrun.__main__.get_test_definitions", return_value="testdef.tar.zst")
+    mocker.patch(
+        "tuxrun.__main__.get_test_definitions", return_value="file://testdef.tar.zst"
+    )
     mocker.patch("tempfile.mkdtemp", return_value=tmpdir)
     mocker.patch("shutil.rmtree")
 
