@@ -1,10 +1,11 @@
 import json
-import pytest
 import os
+
+import pytest
 import yaml
 
 import tuxrun.__main__
-from tuxrun.__main__ import start, main
+from tuxrun.__main__ import main, start
 
 
 def touch(directory, name):
@@ -48,7 +49,7 @@ def tuxrun_args_generate(monkeypatch):
         "--device",
         "qemu-i386",
         "--kernel",
-        "https://storage.tuxboot.com/i386/bzImage",
+        "https://storage.tuxboot.com/buildroot/i386/bzImage",
     ]
     monkeypatch.setattr("sys.argv", args)
     return args
@@ -125,7 +126,7 @@ FVP_MORELLO_ARGS = [
         ["--device", "qemu-armv7", "--tests", "kselftest-arm64"],
         ["--device", "qemu-arm64", "--bios", "bios.bin"],
         ["--device", "qemu-arm64", "--modules", "modules.tar"],
-        ["--kernel", "https://storage.tuxboot.com/i386/bzImage"],
+        ["--kernel", "https://storage.tuxboot.com/buildroot/i386/bzImage"],
         ["--device", "fvp-aemva", "--mcp-fw", "fvp.bin"],
         ["--device", "fvp-aemva", "--modules", "modules.tar"],
         ["--device", "fvp-morello-android", "--mcp-fw", "fvp.bin"],
@@ -156,7 +157,7 @@ FVP_MORELLO_ARGS = [
             "fvp-morello-busybox",
             *FVP_MORELLO_ARGS,
             "--kernel",
-            "https://storage.tuxboot.com/i386/bzImage",
+            "https://storage.tuxboot.com/buildroot/i386/bzImage",
         ],
         ["--device", "fvp-morello-ubuntu", *FVP_MORELLO_ARGS],
         [
@@ -279,7 +280,7 @@ def test_command_line_parameters(monkeypatch, mocker, artefacts):
     run = mocker.patch("tuxrun.__main__.run", return_value=0)
     exitcode = main()
     assert exitcode == 0
-    assert len(run.call_args.args) == 2
+    assert len(run.call_args.args) == 3
     print(run.call_args.parameters)
     assert run.call_args[0][0].parameters == {"USERDATA": "http://userdata.tar.xz"}
 
@@ -574,6 +575,7 @@ def test_update_cache(mocker, monkeypatch, capsys):
   * qemu-armv7
   * qemu-armv7be
   * qemu-i386
+  * qemu-m68k
   * qemu-mips32
   * qemu-mips32el
   * qemu-mips64
