@@ -8,15 +8,16 @@
 import contextlib
 import json
 import logging
-from pathlib import Path
-from os.path import commonprefix
+import re
 import shlex
 import shutil
 import signal
+import subprocess
 import sys
 import tempfile
-import re
-import subprocess
+from os.path import commonprefix
+from pathlib import Path
+from typing import Optional
 from urllib.parse import urlparse
 
 from tuxrun import templates
@@ -29,11 +30,10 @@ from tuxrun.results import Results
 from tuxrun.runtimes import Runtime
 from tuxrun.templates import wrappers
 from tuxrun.tests import Test
-from tuxrun.utils import get_new_output_dir, ProgressIndicator
+from tuxrun.utils import ProgressIndicator, get_new_output_dir
 from tuxrun.writer import Writer
 from tuxrun.yaml import yaml_load
 
-
 ###########
 # GLobals #
 ###########
@@ -145,10 +145,23 @@ def overlay_qemu(qemu_binary, tmpdir, runtime):
     runtime.bind(qemu_binary, dst=dest_path, ro=True)
 
 
+def run_hooks(hooks, cwd):
+    if not hooks:
+        return 0
+    for hook in hooks:
+        try:
+            print(hook)
+            subprocess.check_call(["sh", "-c", hook], cwd=str(cwd))
+        except subprocess.CalledProcessError as e:
+            sys.stderr.write(f"hook `{hook}` failed with exit code {e.returncode}\n")
+            return 2
+    return 0
+
+
 ##############
 # Entrypoint #
 ##############
-def run(options, tmpdir: Path) -> int:
+def run(options, tmpdir: Path, cache_dir: Optional[Path]) -> int:
     # Render the job definition and device dictionary
     extra_assets = []
     overlays = []
@@ -162,7 +175,7 @@ def run(options, tmpdir: Path) -> int:
     # Add test definitions only when needed
     test_definitions = None
     if any(t.need_test_definition for t in options.tests):
-        test_definitions = "file://" + get_test_definitions(
+        test_definitions = get_test_definitions(
             ProgressIndicator.get("Downloading test definitions")
         )
         extra_assets.append(test_definitions)
@@ -317,7 +330,16 @@ def run(options, tmpdir: Path) -> int:
             sys.stdout.write(json.dumps(results.data) + "\n")
         else:
             options.results.write_text(json.dumps(results.data))
-    return max([runtime.ret(), results.ret()])
+
+    if options.lava_definition and cache_dir:
+        (cache_dir / "definition.yaml").write_text(definition, encoding="utf-8")
+
+    # Run results-hooks only if everything was successful
+    if cache_dir:
+        print(f"TuxRun outputs saved to {cache_dir}")
+    return max([runtime.ret(), results.ret()]) or run_hooks(
+        options.results_hooks, cache_dir
+    )
 
 
 def main() -> int:
@@ -346,6 +368,10 @@ def main() -> int:
                 )
 
     cache_dir = None
+    if options.lava_definition:
+        options.save_outputs = True
+    if options.results_hooks:
+        options.save_outputs = True
     if options.save_outputs:
         if any(
             o is None
@@ -357,7 +383,7 @@ def main() -> int:
                 options.results,
             ]
         ):
-            cache_dir = get_new_output_dir()
+            cache_dir = get_new_output_dir(options.cache_dir)
             if options.log_file is None:
                 options.log_file = cache_dir / "logs"
             if options.log_file_html is None:
@@ -403,15 +429,13 @@ def main() -> int:
     tmpdir = Path(tempfile.mkdtemp(prefix="tuxrun-"))
     LOG.debug(f"temporary directory: '{tmpdir}'")
     try:
-        return run(options, tmpdir)
+        return run(options, tmpdir, cache_dir)
     except Exception as exc:
         LOG.error("Raised an exception %s", exc)
         raise
     finally:
         with contextlib.suppress(FileNotFoundError, PermissionError):
             shutil.rmtree(tmpdir)
-        if cache_dir:
-            print(f"TuxRun outputs saved to {cache_dir}")
 
 
 def start():
