@@ -6,16 +6,15 @@
 # SPDX-License-Identifier: MIT
 
 import argparse
-from pathlib import Path
 import sys
-from urllib.parse import urlparse
+from pathlib import Path
 
 from tuxrun import __version__
 from tuxrun.assets import get_rootfs, get_test_definitions
 from tuxrun.devices import Device
 from tuxrun.tests import Test
 from tuxrun.tuxmake import TuxBuildBuild, TuxMakeBuild
-from tuxrun.utils import ProgressIndicator
+from tuxrun.utils import ProgressIndicator, pathurlnone
 
 
 ###########
@@ -31,42 +30,20 @@ def filter_options(options):
         "image",
         "qemu_image",
         "qemu_binary",
+        "cache_dir",
         "save_outputs",
         "log_file",
         "log_file_html",
         "log_file_text",
         "log_file_yaml",
         "results",
+        "results_hooks",
         "debug",
+        "lava_definition",
     ]
     return {k: getattr(options, k) for k in vars(options) if k not in keys}
 
 
-def pathurlnone(string):
-    if string is None:
-        return None
-    url = urlparse(string)
-    if url.scheme in ["http", "https"]:
-        return string
-    if url.scheme not in ["", "file"]:
-        raise argparse.ArgumentTypeError(f"Invalid scheme '{url.scheme}'")
-
-    path = Path(string if url.scheme == "" else url.path)
-    if not path.exists():
-        raise argparse.ArgumentTypeError(f"{path} no such file or directory")
-    return f"file://{path.expanduser().resolve()}"
-
-
-def pathnone(string):
-    if string is None:
-        return None
-
-    path = Path(string)
-    if not path.exists():
-        raise argparse.ArgumentTypeError(f"{path} no such file or directory")
-    return path.expanduser().resolve()
-
-
 def tuxbuild_url(s):
     try:
         return TuxBuildBuild(s.rstrip("/"))
@@ -293,7 +270,7 @@ def setup_parser() -> argparse.ArgumentParser:
     )
     group.add_argument(
         "--image",
-        default="docker.io/lavasoftware/lava-dispatcher:latest",
+        default="docker.io/linaro/tuxrun-dispatcher:latest",
         help="Image to use",
     )
     group.add_argument(
@@ -308,6 +285,12 @@ def setup_parser() -> argparse.ArgumentParser:
     )
 
     group = parser.add_argument_group("output")
+    group.add_argument(
+        "--cache-dir",
+        default=None,
+        type=Path,
+        help="Change the cache directory for storing log files, default: XDG_CACHE_DIR",
+    )
     group.add_argument(
         "--save-outputs",
         default=False,
@@ -324,9 +307,23 @@ def setup_parser() -> argparse.ArgumentParser:
     group.add_argument(
         "--log-file-yaml", default=None, type=Path, help="Store logs to file as YAML"
     )
+    group.add_argument(
+        "--results-hook",
+        type=str,
+        action="append",
+        dest="results_hooks",
+        metavar="COMMAND",
+        help="Execute COMMAND after the run is finished, if the run is successful. Can be specified multiple times. The command is executed with the run output directory (i.e. where all the artifacts are) as working directory. If any results hook fails, tuxrun exits with a non-zero exit code.",
+    )
     group.add_argument(
         "--results", default=None, type=Path, help="Save test results to file (JSON)"
     )
+    group.add_argument(
+        "--lava-definition",
+        default=False,
+        action="store_true",
+        help="Save the LAVA definition.yaml file",
+    )
 
     group = parser.add_argument_group("debugging")
     group.add_argument(
