@@ -11,22 +11,22 @@ import time
 from urllib.parse import urlparse
 
 import requests
+
 from tuxrun.requests import requests_get
-from tuxrun.utils import ProgressIndicator, NoProgressIndicator
+from tuxrun.utils import NoProgressIndicator, ProgressIndicator, pathurlnone
 from tuxrun.xdg import get_cache_dir
 
-
-TEST_DEFINITIONS = "https://storage.tuxboot.com/test-definitions/2023.03.tar.zst"
+TEST_DEFINITIONS = "https://storage.tuxboot.com/test-definitions/2023.08.tar.zst"
 
 
 def get_rootfs(
-    device, rootfs: str = None, progress: ProgressIndicator = NoProgressIndicator()
+    device, rootfs: str = "", progress: ProgressIndicator = NoProgressIndicator()
 ) -> str:
     return __download_and_cache__(rootfs or device.rootfs, progress)
 
 
 def get_test_definitions(progress: ProgressIndicator = NoProgressIndicator()):
-    return __download_and_cache__(TEST_DEFINITIONS, progress)
+    return pathurlnone(__download_and_cache__(TEST_DEFINITIONS, progress))
 
 
 def __download_and_cache__(
@@ -64,7 +64,8 @@ def __download_and_cache__(
         if cache.exists():
             print(e, "Continuing with cached version of the file", file=sys.stderr)
             return str(cache)
-        raise
+        # return url as LAVA will check if it exists and it will show up in the logfile.
+        return url
 
     if cache_etag_file.exists():
         cache_etag = cache_etag_file.read_text()
