@@ -4,12 +4,10 @@
 #
 # SPDX-License-Identifier: MIT
 
-from requests.adapters import HTTPAdapter
-from requests.packages import urllib3
-from requests.packages.urllib3.util.retry import Retry
-
 import requests
-
+from requests.adapters import HTTPAdapter
+from requests.packages import urllib3  # type: ignore
+from requests.packages.urllib3.util.retry import Retry  # type: ignore
 
 timeout = 60
 
