@@ -57,6 +57,7 @@ class Test:
 import tuxrun.tests.commands  # noqa: E402
 import tuxrun.tests.kselftest  # noqa: E402
 import tuxrun.tests.kunit  # noqa: E402
+import tuxrun.tests.kvmunittests  # noqa: E402
 import tuxrun.tests.libgpiod  # noqa: E402
 import tuxrun.tests.libhugetlbfs  # noqa: E402
 import tuxrun.tests.ltp  # noqa: E402
@@ -64,3 +65,4 @@ import tuxrun.tests.morello  # noqa: E402,F401
 import tuxrun.tests.perf  # noqa: E402,F401
 import tuxrun.tests.rcutorture  # noqa: E402,F401
 import tuxrun.tests.v4l2  # noqa: E402,F401
+import tuxrun.tests.vdso  # noqa: E402,F401
